summaryrefslogtreecommitdiffstats
path: root/libkscan
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commite7366c97c998679efa80cf61c88e64a11a3d3c33 (patch)
treea161d2940165f6cc47c05f0271ad8e5f64ffe6e8 /libkscan
parentda4be7880ff1de6415ab6256afd2514e64f5fa2e (diff)
downloadtdegraphics-e7366c97c998679efa80cf61c88e64a11a3d3c33.tar.gz
tdegraphics-e7366c97c998679efa80cf61c88e64a11a3d3c33.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdegraphics@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'libkscan')
-rw-r--r--libkscan/devselector.cpp4
-rw-r--r--libkscan/devselector.h4
-rw-r--r--libkscan/dispgamma.cpp2
-rw-r--r--libkscan/dispgamma.h2
-rw-r--r--libkscan/gammadialog.cpp4
-rw-r--r--libkscan/gammadialog.h2
-rw-r--r--libkscan/img_canvas.cpp4
-rw-r--r--libkscan/img_canvas.h2
-rw-r--r--libkscan/imgscaledialog.cpp4
-rw-r--r--libkscan/imgscaledialog.h2
-rw-r--r--libkscan/kscandevice.cpp8
-rw-r--r--libkscan/kscandevice.h8
-rw-r--r--libkscan/kscanoption.cpp30
-rw-r--r--libkscan/kscanoption.h8
-rw-r--r--libkscan/kscanslider.cpp16
-rw-r--r--libkscan/kscanslider.h14
-rw-r--r--libkscan/massscandialog.cpp4
-rw-r--r--libkscan/massscandialog.h2
-rw-r--r--libkscan/previewer.cpp4
-rw-r--r--libkscan/previewer.h2
-rw-r--r--libkscan/scandialog.cpp12
-rw-r--r--libkscan/scandialog.h6
-rw-r--r--libkscan/scanparams.cpp4
-rw-r--r--libkscan/scanparams.h2
-rw-r--r--libkscan/scansourcedialog.cpp4
-rw-r--r--libkscan/scansourcedialog.h2
-rw-r--r--libkscan/sizeindicator.cpp4
-rw-r--r--libkscan/sizeindicator.h2
28 files changed, 81 insertions, 81 deletions
diff --git a/libkscan/devselector.cpp b/libkscan/devselector.cpp
index bbed0f3b..97b06e54 100644
--- a/libkscan/devselector.cpp
+++ b/libkscan/devselector.cpp
@@ -41,9 +41,9 @@
#include "devselector.h"
-DeviceSelector::DeviceSelector( TQWidget *tqparent, TQStrList& devList,
+DeviceSelector::DeviceSelector( TQWidget *parent, TQStrList& devList,
const TQStringList& hrdevList )
- : KDialogBase( tqparent, "DeviceSel", true, i18n("Welcome to Kooka"),
+ : KDialogBase( parent, "DeviceSel", true, i18n("Welcome to Kooka"),
Ok|Cancel, Ok, true )
{
kdDebug(29000) << "Starting DevSelector!" << endl;
diff --git a/libkscan/dispgamma.cpp b/libkscan/dispgamma.cpp
index a2815276..bb10e8b5 100644
--- a/libkscan/dispgamma.cpp
+++ b/libkscan/dispgamma.cpp
@@ -22,7 +22,7 @@
#include "dispgamma.h"
-DispGamma::DispGamma( TQWidget *tqparent ) : TQWidget( tqparent )
+DispGamma::DispGamma( TQWidget *parent ) : TQWidget( parent )
{
vals = 0;
margin = 10;
diff --git a/libkscan/dispgamma.h b/libkscan/dispgamma.h
index dca8840d..4b8fff45 100644
--- a/libkscan/dispgamma.h
+++ b/libkscan/dispgamma.h
@@ -37,7 +37,7 @@ class DispGamma : public TQWidget {
Q_OBJECT
TQ_OBJECT
public:
- DispGamma( TQWidget *tqparent );
+ DispGamma( TQWidget *parent );
~DispGamma();
TQSize tqsizeHint( void );
diff --git a/libkscan/gammadialog.cpp b/libkscan/gammadialog.cpp
index b61a3388..e1147b10 100644
--- a/libkscan/gammadialog.cpp
+++ b/libkscan/gammadialog.cpp
@@ -29,8 +29,8 @@
#include "gammadialog.h"
-GammaDialog::GammaDialog( TQWidget *tqparent ) :
- KDialogBase( tqparent, "GammaDialog", true, i18n("Custom Gamma Tables"),
+GammaDialog::GammaDialog( TQWidget *parent ) :
+ KDialogBase( parent, "GammaDialog", true, i18n("Custom Gamma Tables"),
Ok|Cancel|Apply, Ok, true )
{
gt = new KGammaTable();
diff --git a/libkscan/gammadialog.h b/libkscan/gammadialog.h
index a4edea12..619e103b 100644
--- a/libkscan/gammadialog.h
+++ b/libkscan/gammadialog.h
@@ -46,7 +46,7 @@ class GammaDialog : public KDialogBase
// TQ_PROPERTY( KGammaTable *gt READ getGt WRITE setGt )
public:
- GammaDialog ( TQWidget *tqparent );
+ GammaDialog ( TQWidget *parent );
~GammaDialog( );
KGammaTable *getGt( ) const { return gt; }
diff --git a/libkscan/img_canvas.cpp b/libkscan/img_canvas.cpp
index 1ecc7970..b510f55d 100644
--- a/libkscan/img_canvas.cpp
+++ b/libkscan/img_canvas.cpp
@@ -72,10 +72,10 @@ public:
TQValueList<TQRect> highlightRects;
};
-ImageCanvas::ImageCanvas(TQWidget *tqparent,
+ImageCanvas::ImageCanvas(TQWidget *parent,
const TQImage *start_image,
const char *name ):
- TQScrollView( tqparent, name ),
+ TQScrollView( parent, name ),
m_contextMenu(0)
{
d = new ImageCanvasPrivate();
diff --git a/libkscan/img_canvas.h b/libkscan/img_canvas.h
index b99cb630..eac68e75 100644
--- a/libkscan/img_canvas.h
+++ b/libkscan/img_canvas.h
@@ -82,7 +82,7 @@ class ImageCanvas: public TQScrollView
TQ_PROPERTY( int scale_factor READ getScaleFactor WRITE setScaleFactor )
public:
- ImageCanvas( TQWidget *tqparent = 0,
+ ImageCanvas( TQWidget *parent = 0,
const TQImage *start_image = 0,
const char *name = 0);
~ImageCanvas( );
diff --git a/libkscan/imgscaledialog.cpp b/libkscan/imgscaledialog.cpp
index 85c793e3..f6319a5b 100644
--- a/libkscan/imgscaledialog.cpp
+++ b/libkscan/imgscaledialog.cpp
@@ -27,9 +27,9 @@
/* ############################################################################## */
-ImgScaleDialog::ImgScaleDialog( TQWidget *tqparent, int curr_sel,
+ImgScaleDialog::ImgScaleDialog( TQWidget *parent, int curr_sel,
const char *name )
- :KDialogBase( tqparent, name , true, i18n("Zoom"),
+ :KDialogBase( parent, name , true, i18n("Zoom"),
Ok|Cancel, Ok, true )
{
// setCaption (i18n ("Image Zoom"));
diff --git a/libkscan/imgscaledialog.h b/libkscan/imgscaledialog.h
index 78c62b43..b6a947ed 100644
--- a/libkscan/imgscaledialog.h
+++ b/libkscan/imgscaledialog.h
@@ -36,7 +36,7 @@ class ImgScaleDialog : public KDialogBase
TQ_PROPERTY( int selected READ getSelected WRITE setSelValue )
public:
- ImgScaleDialog( TQWidget *tqparent, int curr_sel = 100,
+ ImgScaleDialog( TQWidget *parent, int curr_sel = 100,
const char *name = 0 );
public slots:
diff --git a/libkscan/kscandevice.cpp b/libkscan/kscandevice.cpp
index 3aa8571e..a654a075 100644
--- a/libkscan/kscandevice.cpp
+++ b/libkscan/kscandevice.cpp
@@ -109,7 +109,7 @@ KScanOption *KScanDevice::getExistingGuiElement( const TQCString& name )
------------------------------------------------------------------------- */
-KScanOption *KScanDevice::getGuiElement( const TQCString& name, TQWidget *tqparent,
+KScanOption *KScanDevice::getGuiElement( const TQCString& name, TQWidget *parent,
const TQString& desc,
const TQString& tooltip )
{
@@ -132,7 +132,7 @@ KScanOption *KScanDevice::getGuiElement( const TQCString& name, TQWidget *tqpare
/** store new gui-elem in list of all gui-elements */
gui_elements.append( so );
- w = so->createWidget( tqparent, desc, tooltip );
+ w = so->createWidget( parent, desc, tooltip );
if( w )
{
connect( so, TQT_SIGNAL( optionChanged( KScanOption* ) ),
@@ -163,8 +163,8 @@ KScanOption *KScanDevice::getGuiElement( const TQCString& name, TQWidget *tqpare
// ---------------------------------------------------------------------------
-KScanDevice::KScanDevice( TQObject *tqparent )
- : TQObject( tqparent )
+KScanDevice::KScanDevice( TQObject *parent )
+ : TQObject( parent )
{
SANE_Status sane_stat = sane_init(NULL, NULL );
diff --git a/libkscan/kscanoption.cpp b/libkscan/kscanoption.cpp
index 247ed05c..43b35d0b 100644
--- a/libkscan/kscanoption.cpp
+++ b/libkscan/kscanoption.cpp
@@ -317,15 +317,15 @@ void KScanOption::slRedrawWidget( KScanOption *so )
break;
case GAMMA_TABLE:
/* Widget Type is GammaTable */
- // w = new TQSlider( tqparent, "AUTO_GAMMA" );
+ // w = new TQSlider( parent, "AUTO_GAMMA" );
break;
case STR_LIST:
- // w = comboBox( tqparent, text );
+ // w = comboBox( parent, text );
((KScanCombo*)w)->slSetEntry( so->get() );
/* Widget Type is Selection Box */
break;
case STRING:
- // w = entryField( tqparent, text );
+ // w = entryField( parent, text );
((KScanEntry*)w)->slSetEntry( so->get() );
/* Widget Type is Selection Box */
break;
@@ -1059,7 +1059,7 @@ bool KScanOption::getRange( double *min, double *max, double *q ) const
return( ret );
}
-TQWidget *KScanOption::createWidget( TQWidget *tqparent, const TQString& w_desc,
+TQWidget *KScanOption::createWidget( TQWidget *parent, const TQString& w_desc,
const TQString& tooltip )
{
TQStrList list;
@@ -1084,7 +1084,7 @@ TQWidget *KScanOption::createWidget( TQWidget *tqparent, const TQString& w_desc,
{
case BOOL:
/* Widget Type is ToggleButton */
- w = new TQCheckBox( text, tqparent, "AUTO_TOGGLE_BUTTON" );
+ w = new TQCheckBox( text, parent, "AUTO_TOGGLE_BUTTON" );
connect( w, TQT_SIGNAL(clicked()), this,
TQT_SLOT(slWidgetChange()));
break;
@@ -1095,20 +1095,20 @@ TQWidget *KScanOption::createWidget( TQWidget *tqparent, const TQString& w_desc,
break;
case RANGE:
/* Widget Type is Slider */
- w = KSaneSlider( tqparent, text );
+ w = KSaneSlider( parent, text );
break;
case GAMMA_TABLE:
/* Widget Type is Slider */
- // w = KSaneSlider( tqparent, text );
+ // w = KSaneSlider( parent, text );
kdDebug(29000) << "can not create widget for GAMMA_TABLE!" << endl;
w = 0; // No widget, needs to be a set !
break;
case STR_LIST:
- w = comboBox( tqparent, text );
+ w = comboBox( parent, text );
/* Widget Type is Selection Box */
break;
case STRING:
- w = entryField( tqparent, text );
+ w = entryField( parent, text );
/* Widget Type is Selection Box */
break;
default:
@@ -1137,11 +1137,11 @@ TQWidget *KScanOption::createWidget( TQWidget *tqparent, const TQString& w_desc,
}
-TQWidget *KScanOption::comboBox( TQWidget *tqparent, const TQString& text )
+TQWidget *KScanOption::comboBox( TQWidget *parent, const TQString& text )
{
TQStrList list = getList();
- KScanCombo *cb = new KScanCombo( tqparent, text, list);
+ KScanCombo *cb = new KScanCombo( parent, text, list);
connect( cb, TQT_SIGNAL( valueChanged( const TQCString& )), this,
TQT_SLOT( slWidgetChange( const TQCString& )));
@@ -1150,9 +1150,9 @@ TQWidget *KScanOption::comboBox( TQWidget *tqparent, const TQString& text )
}
-TQWidget *KScanOption::entryField( TQWidget *tqparent, const TQString& text )
+TQWidget *KScanOption::entryField( TQWidget *parent, const TQString& text )
{
- KScanEntry *ent = new KScanEntry( tqparent, text );
+ KScanEntry *ent = new KScanEntry( parent, text );
connect( ent, TQT_SIGNAL( valueChanged( TQCString )), this,
TQT_SLOT( slWidgetChange( TQCString )));
@@ -1160,12 +1160,12 @@ TQWidget *KScanOption::entryField( TQWidget *tqparent, const TQString& text )
}
-TQWidget *KScanOption::KSaneSlider( TQWidget *tqparent, const TQString& text )
+TQWidget *KScanOption::KSaneSlider( TQWidget *parent, const TQString& text )
{
double min, max, quant;
getRange( &min, &max, &quant );
- KScanSlider *slider = new KScanSlider( tqparent, text, min, max );
+ KScanSlider *slider = new KScanSlider( parent, text, min, max );
/* Connect to the options change Slot */
connect( slider, TQT_SIGNAL( valueChanged(int)), this,
TQT_SLOT( slWidgetChange(int)));
diff --git a/libkscan/kscanoption.h b/libkscan/kscanoption.h
index d26ddd10..5a4e4271 100644
--- a/libkscan/kscanoption.h
+++ b/libkscan/kscanoption.h
@@ -149,7 +149,7 @@ public:
*
**/
- TQWidget *createWidget( TQWidget *tqparent,
+ TQWidget *createWidget( TQWidget *parent,
const TQString& w_desc = TQString(),
const TQString& tooltip = TQString() );
@@ -238,9 +238,9 @@ private:
bool initOption( const TQCString& new_name );
void *allocBuffer( long );
- TQWidget *entryField ( TQWidget *tqparent, const TQString& text );
- TQWidget *KSaneSlider( TQWidget *tqparent, const TQString& text );
- TQWidget *comboBox ( TQWidget *tqparent, const TQString& text );
+ TQWidget *entryField ( TQWidget *parent, const TQString& text );
+ TQWidget *KSaneSlider( TQWidget *parent, const TQString& text );
+ TQWidget *comboBox ( TQWidget *parent, const TQString& text );
const SANE_Option_Descriptor *desc;
TQCString name;
diff --git a/libkscan/kscanslider.cpp b/libkscan/kscanslider.cpp
index 1712f2be..742a0bb6 100644
--- a/libkscan/kscanslider.cpp
+++ b/libkscan/kscanslider.cpp
@@ -31,10 +31,10 @@
#include <kdebug.h>
#include "kscanslider.h"
-KScanSlider::KScanSlider( TQWidget *tqparent, const TQString& text,
+KScanSlider::KScanSlider( TQWidget *parent, const TQString& text,
double min, double max, bool haveStdButt,
int stdValue )
- : TQFrame( tqparent ),
+ : TQFrame( parent ),
m_stdValue( stdValue ),
m_stdButt(0)
{
@@ -149,8 +149,8 @@ KScanSlider::~KScanSlider()
/* ====================================================================== */
-KScanEntry::KScanEntry( TQWidget *tqparent, const TQString& text )
- : TQFrame( tqparent )
+KScanEntry::KScanEntry( TQWidget *parent, const TQString& text )
+ : TQFrame( parent )
{
TQHBoxLayout *hb = new TQHBoxLayout( this );
@@ -213,9 +213,9 @@ void KScanEntry::slReturnPressed( void )
-KScanCombo::KScanCombo( TQWidget *tqparent, const TQString& text,
+KScanCombo::KScanCombo( TQWidget *parent, const TQString& text,
const TQStrList& list )
- : TQHBox( tqparent ),
+ : TQHBox( parent ),
combo(0)
{
createCombo( text );
@@ -224,9 +224,9 @@ KScanCombo::KScanCombo( TQWidget *tqparent, const TQString& text,
combolist = list;
}
-KScanCombo::KScanCombo( TQWidget *tqparent, const TQString& text,
+KScanCombo::KScanCombo( TQWidget *parent, const TQString& text,
const TQStringList& list )
- : TQHBox( tqparent ),
+ : TQHBox( parent ),
combo(0)
{
createCombo( text );
diff --git a/libkscan/massscandialog.cpp b/libkscan/massscandialog.cpp
index 372d2a7c..9d4a5f91 100644
--- a/libkscan/massscandialog.cpp
+++ b/libkscan/massscandialog.cpp
@@ -30,8 +30,8 @@
#include "massscandialog.h"
-MassScanDialog::MassScanDialog( TQWidget *tqparent )
- :TQDialog( tqparent, "MASS_SCAN", true )
+MassScanDialog::MassScanDialog( TQWidget *parent )
+ :TQDialog( parent, "MASS_SCAN", true )
{
setCaption( i18n( "ADF Scanning" ));
kdDebug(29000) << "Starting MassScanDialog!" << endl;
diff --git a/libkscan/massscandialog.h b/libkscan/massscandialog.h
index 1cd68153..479913a8 100644
--- a/libkscan/massscandialog.h
+++ b/libkscan/massscandialog.h
@@ -35,7 +35,7 @@ class MassScanDialog : public TQDialog
Q_OBJECT
TQ_OBJECT
public:
- MassScanDialog( TQWidget *tqparent);
+ MassScanDialog( TQWidget *parent);
~MassScanDialog();
public slots:
diff --git a/libkscan/previewer.cpp b/libkscan/previewer.cpp
index 5fde3f06..0e6c8804 100644
--- a/libkscan/previewer.cpp
+++ b/libkscan/previewer.cpp
@@ -106,8 +106,8 @@ public:
TQMemArray<long> m_widthSum;
};
-Previewer::Previewer(TQWidget *tqparent, const char *name )
- : TQWidget(tqparent,name)
+Previewer::Previewer(TQWidget *parent, const char *name )
+ : TQWidget(parent,name)
{
d = new PreviewerPrivate();
diff --git a/libkscan/previewer.h b/libkscan/previewer.h
index 45a270ea..b1400e3a 100644
--- a/libkscan/previewer.h
+++ b/libkscan/previewer.h
@@ -45,7 +45,7 @@ class Previewer : public TQWidget
Q_OBJECT
TQ_OBJECT
public:
- Previewer(TQWidget *tqparent=0, const char *name=0);
+ Previewer(TQWidget *parent=0, const char *name=0);
~Previewer();
ImageCanvas *getImageCanvas( void ){ return( img_canvas ); }
diff --git a/libkscan/scandialog.cpp b/libkscan/scandialog.cpp
index bc9a7854..8d762272 100644
--- a/libkscan/scandialog.cpp
+++ b/libkscan/scandialog.cpp
@@ -51,25 +51,25 @@ extern "C" {
}
}
-ScanDialogFactory::ScanDialogFactory( TQObject *tqparent, const char *name )
- : KScanDialogFactory( tqparent, name )
+ScanDialogFactory::ScanDialogFactory( TQObject *parent, const char *name )
+ : KScanDialogFactory( parent, name )
{
setName( "ScanDialogFactory" );
KGlobal::locale()->insertCatalogue( TQString::tqfromLatin1("libkscan") );
}
-KScanDialog * ScanDialogFactory::createDialog( TQWidget *tqparent,
+KScanDialog * ScanDialogFactory::createDialog( TQWidget *parent,
const char *name, bool modal)
{
- return new ScanDialog( tqparent, name, modal );
+ return new ScanDialog( parent, name, modal );
}
///////////////////////////////////////////////////////////////////
-ScanDialog::ScanDialog( TQWidget *tqparent, const char *name, bool modal )
- : KScanDialog( Tabbed, Close|Help, tqparent, name, modal ),
+ScanDialog::ScanDialog( TQWidget *parent, const char *name, bool modal )
+ : KScanDialog( Tabbed, Close|Help, parent, name, modal ),
good_scan_connect(false)
{
TQVBox *page = addVBoxPage( i18n("&Scanning") );
diff --git a/libkscan/scandialog.h b/libkscan/scandialog.h
index 5077f050..1069e816 100644
--- a/libkscan/scandialog.h
+++ b/libkscan/scandialog.h
@@ -35,7 +35,7 @@ class ScanDialog : public KScanDialog
TQ_OBJECT
public:
- ScanDialog( TQWidget *tqparent=0, const char *name=0, bool modal=false );
+ ScanDialog( TQWidget *parent=0, const char *name=0, bool modal=false );
~ScanDialog();
virtual bool setup();
@@ -72,10 +72,10 @@ private:
class ScanDialogFactory : public KScanDialogFactory
{
public:
- ScanDialogFactory( TQObject *tqparent=0, const char *name=0 );
+ ScanDialogFactory( TQObject *parent=0, const char *name=0 );
protected:
- virtual KScanDialog * createDialog( TQWidget *tqparent=0, const char *name=0,
+ virtual KScanDialog * createDialog( TQWidget *parent=0, const char *name=0,
bool modal=false );
diff --git a/libkscan/scanparams.cpp b/libkscan/scanparams.cpp
index 9cd0f3ab..ec9e77fe 100644
--- a/libkscan/scanparams.cpp
+++ b/libkscan/scanparams.cpp
@@ -53,8 +53,8 @@
-ScanParams::ScanParams( TQWidget *tqparent, const char *name )
- : TQVBox( tqparent, name ),
+ScanParams::ScanParams( TQWidget *parent, const char *name )
+ : TQVBox( parent, name ),
m_firstGTEdit( true )
{
/* first some initialisation and debug messages */
diff --git a/libkscan/scanparams.h b/libkscan/scanparams.h
index d3536e42..a9f29d0e 100644
--- a/libkscan/scanparams.h
+++ b/libkscan/scanparams.h
@@ -49,7 +49,7 @@ class ScanParams : public TQVBox
Q_OBJECT
TQ_OBJECT
public:
- ScanParams( TQWidget *tqparent, const char *name = 0);
+ ScanParams( TQWidget *parent, const char *name = 0);
~ScanParams();
#if 0
TQSize tqsizeHint( );
diff --git a/libkscan/scansourcedialog.cpp b/libkscan/scansourcedialog.cpp
index 2edac6f8..fcb3fc25 100644
--- a/libkscan/scansourcedialog.cpp
+++ b/libkscan/scansourcedialog.cpp
@@ -45,8 +45,8 @@ extern "C"{
#endif
-ScanSourceDialog::ScanSourceDialog( TQWidget *tqparent, const TQStrList list, ADF_BEHAVE adfBehave )
- : KDialogBase( tqparent, "SOURCE_DIALOG", true, i18n("Scan Source Selection"),
+ScanSourceDialog::ScanSourceDialog( TQWidget *parent, const TQStrList list, ADF_BEHAVE adfBehave )
+ : KDialogBase( parent, "SOURCE_DIALOG", true, i18n("Scan Source Selection"),
Ok|Cancel,Ok, true)
{
TQVBox *vbox = makeVBoxMainWidget();
diff --git a/libkscan/scansourcedialog.h b/libkscan/scansourcedialog.h
index 3b0662d8..dbf2cc74 100644
--- a/libkscan/scansourcedialog.h
+++ b/libkscan/scansourcedialog.h
@@ -39,7 +39,7 @@ class ScanSourceDialog : public KDialogBase
Q_OBJECT
TQ_OBJECT
public:
- ScanSourceDialog( TQWidget *tqparent, const TQStrList, ADF_BEHAVE );
+ ScanSourceDialog( TQWidget *parent, const TQStrList, ADF_BEHAVE );
~ScanSourceDialog();
// void fillWithSources( TQStrList *list );
diff --git a/libkscan/sizeindicator.cpp b/libkscan/sizeindicator.cpp
index 3b0a2a18..582f2330 100644
--- a/libkscan/sizeindicator.cpp
+++ b/libkscan/sizeindicator.cpp
@@ -29,8 +29,8 @@
-SizeIndicator::SizeIndicator( TQWidget *tqparent, long thres, long crit )
- :TQLabel( tqparent )
+SizeIndicator::SizeIndicator( TQWidget *parent, long thres, long crit )
+ :TQLabel( parent )
{
sizeInByte = -1;
setFrameStyle( TQFrame::Box | TQFrame::Sunken );
diff --git a/libkscan/sizeindicator.h b/libkscan/sizeindicator.h
index 0d248fec..52f2e8b1 100644
--- a/libkscan/sizeindicator.h
+++ b/libkscan/sizeindicator.h
@@ -50,7 +50,7 @@ public:
* @param crit: Critical value, not yet used.
*/
- SizeIndicator( TQWidget *tqparent, long thres = DEFAULT_THRESHOLD,
+ SizeIndicator( TQWidget *parent, long thres = DEFAULT_THRESHOLD,
long crit = DEFAULT_CRITICAL );
/**
* destructor does not really do much yet.
diff --git a/libkscan/devselector.h b/libkscan/devselector.h
index ec74f343..de478285 100644
--- a/libkscan/devselector.h
+++ b/libkscan/devselector.h
@@ -58,11 +58,11 @@ class DeviceSelector: public KDialogBase
public:
/**
* constructs the dialog class
* @param TQWidget *tqparent - the tqparent
* @param TQStrList backends - a list of device names retrieved from the scan device
* @param TQStrList scannerNames - a list of corresponding human readable sanner names.
*/
- DeviceSelector( TQWidget *tqparent, TQStrList&, const TQStringList& );
+ DeviceSelector( TQWidget *parent, TQStrList&, const TQStringList& );
~DeviceSelector();
/**
@@ -58,11 +58,11 @@ class DeviceSelector: public KDialogBase
/**
* constructs the dialog class
- * @param TQWidget *tqparent - the tqparent
+ * @param TQWidget *parent - the parent
* @param TQStrList backends - a list of device names retrieved from the scan device
* @param TQStrList scannerNames - a list of corresponding human readable sanner names.
diff --git a/libkscan/kscandevice.h b/libkscan/kscandevice.h
index 06a28cfa..7cf8471b 100644
--- a/libkscan/kscandevice.h
+++ b/libkscan/kscandevice.h
@@ -76,7 +76,7 @@ public:
*
*/
- KScanDevice( TQObject *tqparent = 0 );
+ KScanDevice( TQObject *parent = 0 );
/**
* Destructor
@@ -246,11 +246,11 @@ public:
* KScanOption. It is internally connected to the scan device, every
* change to the widget is automaticly considered by the scan device.
* @param name: Name of the SANE Option
* @param tqparent: pointer to the tqparent widget
* @param desc: pointer to the text appearing as widget text
* @param tooltip: tooltip text. If zero, the SANE text will be used.
**/
- KScanOption *getGuiElement( const TQCString& name, TQWidget *tqparent,
+ KScanOption *getGuiElement( const TQCString& name, TQWidget *parent,
const TQString& desc = TQString(),
const TQString& tooltip = TQString() );
@@ -423,7 +423,7 @@ private:
KScanStat createNewImage( SANE_Parameters *p );
// not implemented
// TQWidget *entryField( TQWidget *tqparent, const TQString& text,
// const TQString& tooltip );
KScanStat find_options(); // help fct. to process options
KScanStat acquire_data( bool isPreview = false );
@@ -246,11 +246,11 @@ public:
* change to the widget is automaticly considered by the scan device.
* @param name: Name of the SANE Option
- * @param tqparent: pointer to the tqparent widget
+ * @param parent: pointer to the parent widget
* @param desc: pointer to the text appearing as widget text
* @param tooltip: tooltip text. If zero, the SANE text will be used.
@@ -423,7 +423,7 @@ private:
KScanStat createNewImage( SANE_Parameters *p );
// not implemented
-// TQWidget *entryField( TQWidget *tqparent, const TQString& text,
+// TQWidget *entryField( TQWidget *parent, const TQString& text,
// const TQString& tooltip );
KScanStat find_options(); // help fct. to process options
diff --git a/libkscan/kscanslider.h b/libkscan/kscanslider.h
index 30fc6464..b7d9a27e 100644
--- a/libkscan/kscanslider.h
+++ b/libkscan/kscanslider.h
@@ -52,7 +52,7 @@ public:
/**
* Create the slider.
*
* @param tqparent tqparent widget
* @param text is the text describing the the slider value. If the text
* contains a '&', a buddy for the slider will be created.
* @param min minimum slider value
@@ -61,7 +61,7 @@ public:
* appears on the left of the slider.
* @param stdValue the value to which the standard button resets the slider.
*/
- KScanSlider( TQWidget *tqparent, const TQString& text,
+ KScanSlider( TQWidget *parent, const TQString& text,
double min, double max, bool haveStdButt=false,
int stdValue=0);
/**
@@ -124,10 +124,10 @@ class KScanEntry : public TQFrame
public:
/**
* create a new entry field prepended by text.
* @param tqparent the tqparent widget
* @text the prefix text
*/
- KScanEntry( TQWidget *tqparent, const TQString& text );
+ KScanEntry( TQWidget *parent, const TQString& text );
// ~KScanEntry();
/**
@@ -179,12 +179,12 @@ public:
/**
* create a combobox with prepended text.
*
* @param tqparent tqparent widget
* @param text the text the combobox is prepended by
* @param list a stringlist with values the list should contain.
*/
- KScanCombo( TQWidget *tqparent, const TQString& text, const TQStrList& list );
- KScanCombo( TQWidget *tqparent, const TQString& text, const TQStringList& list );
+ KScanCombo( TQWidget *parent, const TQString& text, const TQStrList& list );
+ KScanCombo( TQWidget *parent, const TQString& text, const TQStringList& list );
// ~KScanCombo();
/**
@@ -52,7 +52,7 @@ public:
* Create the slider.
*
- * @param tqparent tqparent widget
+ * @param parent parent widget
* @param text is the text describing the the slider value. If the text
* contains a '&', a buddy for the slider will be created.
@@ -124,10 +124,10 @@ class KScanEntry : public TQFrame
/**
* create a new entry field prepended by text.
- * @param tqparent the tqparent widget
+ * @param parent the parent widget
* @text the prefix text
*/
@@ -179,12 +179,12 @@ public:
* create a combobox with prepended text.
*
- * @param tqparent tqparent widget
+ * @param parent parent widget
* @param text the text the combobox is prepended by
* @param list a stringlist with values the list should contain.